@@ -82,7 +82,8 @@ class s3_connect(object):
                 'offer_recommender',
                 'offer_recommender_v2',
                 'offer_recommender_v2_1',
-                'complaint_model_v2_0')
+                'complaint_model_v2_0',
+                'reactivation_model_v2_0')
         
         file_location = path to file
         
@@ -102,7 +103,8 @@ class s3_connect(object):
             'offer_recommender',
             'offer_recommender_v2',
             'offer_recommender_v2_1',
-            'complaint_model_v2_0'
+            'complaint_model_v2_0',
+            'reactivation_model_v2_0'
             )
 
         types = ('input', 'output', 'pickled_model')
